4.40. umbra.ui.delegates — Umbra 1.0.9 documentation

# 4.40. umbra.ui.delegates

delegates.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application Delegates classes.

Others:

## 4.40.1. Module Attributes

`umbra.ui.delegates.` `LOGGER`

## 4.40.2. Classes

class `umbra.ui.delegates.` `Style`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  Defines a storage object for the `RichText_QStyledItemDelegate` class style.

  Initializes the class.

  Parameters: | **kwargs (dict) – .

class `umbra.ui.delegates.` `RichText_QStyledItemDelegate`(parent=None, style=None, highlightColor=None, hoverColor=None, backgroundColor=None, highlightBackgroundColor=None, hoverBackgroundColor=None)

  Bases: `PyQt4.QtGui.QStyledItemDelegate`

  Defines a QStyledItemDelegate subclass used as a rich text Delegate for Application Views.

  Initializes the class.

  Parameters: | parent (QObject) – Widget parent. style (Style) – Style.

  `style`

    Property for self.__style attribute.

    Returns: | self.__style.
    Return type: | Style

  `paint`(painter, option, index)

    Reimplements the `QStyledItemDelegate.paint()` method.

  `sizeHint`(option, index)

    Reimplements the `QStyledItemDelegate.sizeHint()` method.